@@ -157,16 +157,17 @@ def main():
             return Color(r, g, b)
 
     parser.add_argument("reports", type=PathSorter(reports, "report"), default=None, nargs="*" if "BAGUETTE_REPORTS" in environ else "+", help="Cuckoo report files (.json) to bake baguettes from. Can also be folders containing reports. Defaults to environment variable 'BAGUETTE_REPORTS' if set.")
-    parser.add_argument("--baguettes", type=PathSorter(baguettes, "baguette"), default=None, action="extend", nargs="*", help="the path(s) to the output (copy) baguette files (.pyt). Use '-' to leave it to the automatic destination. Defaults to environment variable 'BAGUETTE_BAGUETTES' or '-' if not set.")
-    parser.add_argument("--visuals", type=PathSorter(visuals, "visual"), default=None, action="extend", nargs="*", help="the path(s) to the output (copy) visual (Gephi) files (.gexf). Use '-' to leave it to the automatic destination. Defaults to environment variable 'BAGUETTE_VISUALS' or '-' if not set.")
-    parser.add_argument("-o", "--outputs", type=PathSorter(outputs, "output"), default=None, action="extend", nargs="*", help="the path to the result index folders (which end in .bag). They contain the index file (.pyt) which stores all the information about a given baguette. Use '-' to leave it to the automatic destination. Defaults to environment variable 'BAGUETTE_OUTPUTS' or '.' if not set.")
-    parser.add_argument("--pool", type=pool_size, default=pool_size("0.5"), help="the size of the process pool to use to bake in parallel.")
-    parser.add_argument("--maxtime", type=time, default=time("inf"), help="the maximum amount of time spent baking a single baguette. No maxtime by default.")
-    parser.add_argument("-f", "--filters", type=str, default=[], choices=[name for name in dir(filters) if isinstance(getattr(filters, name), filters.Filter)], nargs="*", help="a list of filters that can be used when exporting the baguette to the visual file (.gexf).")
-    parser.add_argument("--perf", action="store_true", default=False, help="if this is enabled, a performance report will be printed at the end of the baking process.")
-    parser.add_argument("-v", "--verbosity", action="count", default=0, help="increases the verbosity of the output.")
-    parser.add_argument("--skip_data_comparison", action="store_true", default=False, help="if enabled, the computation of the Levenshtein similarity between all Data nodes will be skipped.")
-    parser.add_argument("--skip_diff_comparison", action="store_true", default=False, help="same as skip_data_comparison but for Diff nodes.")
+    parser.add_argument("--baguettes", type=PathSorter(baguettes, "baguette"), default=None, action="extend", nargs="*", help="The path(s) to the output (copy) baguette files (.pyt). Use '-' to leave it to the automatic destination. Defaults to environment variable 'BAGUETTE_BAGUETTES' or '-' if not set.")
+    parser.add_argument("--visuals", type=PathSorter(visuals, "visual"), default=None, action="extend", nargs="*", help="The path(s) to the output (copy) visual (Gephi) files (.gexf). Use '-' to leave it to the automatic destination. Defaults to environment variable 'BAGUETTE_VISUALS' or '-' if not set.")
+    parser.add_argument("-o", "--outputs", type=PathSorter(outputs, "output"), default=None, action="extend", nargs="*", help="The path to the result index folders (which end in .bag). They contain the index file (.pyt) which stores all the information about a given baguette. Use '-' to leave it to the automatic destination. Defaults to environment variable 'BAGUETTE_OUTPUTS' or '.' if not set.")
+    parser.add_argument("--pool", type=pool_size, default=pool_size("0.5"), help="The size of the process pool to use to bake in parallel.")
+    parser.add_argument("--maxtime", type=time, default=time("inf"), help="The maximum amount of time spent baking a single baguette. No maxtime by default.")
+    parser.add_argument("-f", "--filters", type=str, default=[], choices=[name for name in dir(filters) if isinstance(getattr(filters, name), filters.Filter)], nargs="*", help="A list of filters that can be used when exporting the baguette to the visual file (.gexf).")
+    parser.add_argument("--perf", action="store_true", default=False, help="If this is enabled, a performance report will be printed at the end of the baking process.")
+    parser.add_argument("-v", "--verbosity", action="count", default=0, help="Increases the verbosity of the output.")
+    parser.add_argument("--skip_data_comparison", action="store_true", default=False, help="If enabled, the computation of the Levenshtein similarity between all Data nodes will be skipped.")
+    parser.add_argument("--skip_diff_comparison", action="store_true", default=False, help="Same as skip_data_comparison but for Diff nodes.")
+    parser.add_argument("--save_filtered_baguette", action="store_true", default=False, help="If enabled, instead of saving the raw BAGUETTE graph in the 'baguette.pyt' file, only the filtered BAGUETTE will be saved.")
     parser.add_argument("--background", type=paint_color, default=Color.black, help="If a color is given for background, the color settings which are close to the background color will be changed to be more visible on that background. Must be a valid color name or RGB values.")
 
 
@@ -449,6 +450,7 @@ def main():
             bg.maxtime = args.maxtime
             bg.perf = args.perf
             bg.background_color = args.background
+            bg.save_filtered_baguette = args.save_filtered_baguette
             work.append((bg, r, b, v))
     
     
