@@ -95,19 +95,29 @@ def compile(rack_path : Path, report_path : Path, cp_baguette : Path | None = No
                 G = b.graph
                 logger.info("Analyzing graph...")
                 logger.info("Got {} vertices and {} edges.".format(G.n, G.m))
-                logger.info("Saving with pickle")
-                rack.baguette.parent.mkdir(parents = True, exist_ok = True)
-                with rack.baguette.open("wb") as file:
-                    dump(G, file)
-                if cp_baguette is not None:
-                    from shutil import copyfile
-                    cp_baguette.parent.mkdir(parents=True, exist_ok=True)
-                    copyfile(rack.baguette, cp_baguette)
+                if not rack.save_filtered_baguette:
+                    logger.info("Saving with pickle")
+                    rack.baguette.parent.mkdir(parents = True, exist_ok = True)
+                    with rack.baguette.open("wb") as file:
+                        dump(G, file)
+                    if cp_baguette is not None:
+                        from shutil import copyfile
+                        cp_baguette.parent.mkdir(parents=True, exist_ok=True)
+                        copyfile(rack.baguette, cp_baguette)
                 filters = rack.filters
                 if filters:
                     for i, (f, name) in enumerate(zip(filters, rack.filter_names)):
                         logger.info("Applying filters {}/{} : {}".format(i + 1, len(filters), name))
                         f.apply(G)
+                if rack.save_filtered_baguette:
+                    logger.info("Saving with pickle")
+                    rack.baguette.parent.mkdir(parents = True, exist_ok = True)
+                    with rack.baguette.open("wb") as file:
+                        dump(G, file)
+                    if cp_baguette is not None:
+                        from shutil import copyfile
+                        cp_baguette.parent.mkdir(parents=True, exist_ok=True)
+                        copyfile(rack.baguette, cp_baguette)
                 logger.info("Exporting to .gexf")
                 rack.visual.parent.mkdir(parents = True, exist_ok = True)
                 G.export(str(rack.visual))
