@@ -31,7 +31,7 @@ def integrate_thread_creation(c : entities.Call):
         t, ok = find_or_create(Thread, TID = c.arguments.thread_identifier)
         l = StartedThread(c, t)
         if c.name in {"CreateRemoteThread", "CreateRemoteThreadEx"}:
-            logger.info("Detected thread injection.")
+            logger.debug("Detected thread injection.")
             l.remote = True
             p = c.thread.process
             InjectedThread(p, t)
