@@ -62,7 +62,7 @@ class Key(UniqueVertex):
         if not self.printable:
             from .....logger import logger
             from ...config import ColorSetting
-            logger.info("Got an unprintable registry key.")
+            logger.debug("Got an unprintable registry key.")
             self.color = self.unprintable_key_color
     
     @property
