@@ -47,7 +47,11 @@ def path_factory(path : str) -> pathlib.PurePath:
     from pathlib import PurePosixPath, PureWindowsPath
 
     from .graph import Graph
-    platform = Graph.active_graphs()[-1].data["platform"].lower() if Graph.active_graphs() else "windows"
+    platform = "windows"
+    for g in Graph.graphs_status():
+        if "platform" in g.data:
+            platform = g.data["platform"].lower()
+            break
     if "windows" in platform:
         return PureWindowsPath(path)
     else:
@@ -93,7 +97,7 @@ def parse_command_line(s : str) -> list[str]:
 
     from .graph import Graph
 
-    platform = Graph.active_graphs()[-1].data["platform"].lower() if Graph.active_graphs() else "windows"
+    platform = Graph.active_graphs()[-1].data["platform"].lower() if Graph.active_graphs() and "platform" in Graph.active_graphs()[-1].data else "windows"
     if "windows" not in platform:
         RE_CMD_LEX = r'''"((?:\\["\\]|[^"])*)"|'([^']*)'|(\\.)|(&&?|\|\|?|\d?\>|[<])|([^\s'"\\&|<>]+)|(\s+)|(.)'''
     else:
