@@ -46,7 +46,8 @@ class BaguetteRack:
         "__maxtime" : "The maximum amount of time to spend on this baguette",
         "__paint_color" : "The color to use to paint MetaGraph matches in the visual file",
         "__suppressed" : "Indicates if an exception should suppress the index file output",
-        "__background_color" : "The color of the background for the visual graph"
+        "__background_color" : "The color of the background for the visual graph",
+        "__save_filtered_baguette" : "Indicates if the Graph has been saved after applying filters"
     }
 
     __pickle_slots__ = {
@@ -62,7 +63,8 @@ class BaguetteRack:
         "maxtime",
         "paint_color",
         "suppressed",
-        "background_color"
+        "background_color",
+        "save_filtered_baguette"
     }
 
     names = {
@@ -93,6 +95,7 @@ class BaguetteRack:
         self.__paint_color : list[Color] | None = None
         self.__suppressed : bool = False
         self.__background_color : Color = Color.black
+        self.__save_filtered_baguette : bool = False
         if not isinstance(working_directory, str | Path):
             raise TypeError("Expected Path, got " + repr(type(working_directory).__name__))
     
@@ -411,6 +414,20 @@ class BaguetteRack:
         if not isinstance(value, bool):
             raise TypeError("Expected bool, got " + repr(type(value).__name__))
         self.__skip_diff_comparison = value
+
+    @property
+    def save_filtered_baguette(self) -> bool:
+        """
+        Indicates if the BAGUETTE Graph was saved after the filtering phase during compilation.
+        If True, the BAGUETTE file and the visual file will actually contain the same graph. Otherwise, the BAGUETTE file contains the file before filtering.
+        """
+        return self.__save_filtered_baguette
+    
+    @save_filtered_baguette.setter
+    def save_filtered_baguette(self, value : bool):
+        if not isinstance(value, bool):
+            raise TypeError("Expected bool, got " + repr(type(value).__name__))
+        self.__save_filtered_baguette = value
         
     def export(self):
         """
@@ -428,7 +445,7 @@ class BaguetteRack:
         Loads the information on a baguette from the given index path.
         """
         from pathlib import Path
-        from pickle import load
+        from pickle import load, UnpicklingError
         if not isinstance(path, str | Path):
             raise TypeError("Expected Path, got " + repr(type(path).__name__))
         if isinstance(path, str):
@@ -437,8 +454,13 @@ class BaguetteRack:
             except BaseException as e:
                 raise e from None
         path = path.expanduser().resolve()
-        with path.open("rb") as f:
-            rack : BaguetteRack = load(f)
+        try:
+            with path.open("rb") as f:
+                rack : BaguetteRack = load(f)
+        except UnpicklingError:
+            raise TypeError(f"Could not load baguette in file '{path}'")
+        if not isinstance(rack, cls):
+            raise TypeError(f"Object in file '{path}' is not a '{cls.__name__}'")
         rack.__working_directory = path.parent
         return rack
     
